@@ -8,7 +8,10 @@ class NounTypes(enum.Enum):
 
     ALCOHOLS = 'alcohols'
     ANIMALS = 'animals'
+    CELESTIALS = 'celestials'
+    DINOSAURS = 'dinosaurs'
     ELEMENTS = 'elements'
+    FISH = 'fish'
     FOODS = 'foods'
     FRUITS = 'fruits'
     GEOGRAPHIES = 'geographies'
